@@ -4,8 +4,12 @@ import sys
 from typing import Dict, Tuple
 
 import click
+from rich.console import Console
+from rich.syntax import Syntax
 
-from dict_typer.convert import convert
+from dict_typer.type_definitions import get_type_definitions
+
+__version__ = "0.1.15"
 
 
 @click.command()
@@ -14,8 +18,18 @@ from dict_typer.convert import convert
     default=True,
     help="Show imports at the top, default: True",
 )
+@click.option("--rich", "-r", is_flag=True, help="Show rich output.")
+@click.option(
+    "--line-numbers", "-l", is_flag=True, help="Show line numbers if rich.",
+)
 @click.argument("file", type=click.File("r"), nargs=-1)
-def cli(file: Tuple[io.TextIOWrapper], imports: bool = True) -> None:
+@click.version_option(__version__)
+def cli(
+    file: Tuple[io.TextIOWrapper],
+    imports: bool = True,
+    rich: bool = False,
+    line_numbers: bool = False,
+) -> None:
     if len(file) > 1:
         raise click.BadArgumentUsage("Multiple files supplied, run with one at a time")
     if len(file) == 0:
@@ -33,6 +47,10 @@ def cli(file: Tuple[io.TextIOWrapper], imports: bool = True) -> None:
     except json.decoder.JSONDecodeError as e:
         raise click.UsageError(f"JSON serialisation error \n\n{e}")
 
-    output = convert(parsed, show_imports=imports)
-
-    click.echo(output)
+    output = get_type_definitions(parsed, show_imports=imports)
+    if rich:
+        syntax = Syntax(output, "python", theme="monokai", line_numbers=line_numbers)
+        console = Console()
+        console.print(syntax)
+    else:
+        click.echo(output)
